@@ -4,7 +4,6 @@ import os
 from functools import lru_cache
 from typing import Any, List, Type
 
-from xtremcache import log_level
 from sqlalchemy import (Boolean, Column, DateTime, Integer, String,
                         create_engine)
 from sqlalchemy.orm import Session, declarative_base
@@ -12,21 +11,22 @@ from sqlalchemy.orm.exc import NoResultFound
 
 from xtremcache.exceptions import *
 from xtremcache.utils import *
+from xtremcache.version import __app_name__
 
 
 class BddManager():
     """Manage database to valid operations on cached files."""
 
-    def __init__(self, data_base_dir: str, verbosity: int = log_level.WARNING) -> None:
+    def __init__(self, data_base_dir: str, log_level: int = logging.WARNING) -> None:
         self.__data_base_dir = os.path.realpath(data_base_dir)
-        self.__verbosity = verbosity
+        self.__log_level = log_level
 
     @property
     @lru_cache
     def __db_location(self) -> str:
         """Path to used database."""
 
-        return os.path.join(self.__data_base_dir, f'{get_app_name()}.db')
+        return os.path.join(self.__data_base_dir, f'{__app_name__}.db')
 
     @property
     def size(self) -> int:
@@ -50,7 +50,7 @@ class BddManager():
         os.makedirs(dir, exist_ok=True)
         engine = create_engine(
             self.__sqlite_db_location,
-            echo=self.__verbosity<log_level.INFO)
+            echo=self.__log_level<logging.INFO)
         return engine
 
     @property
@@ -147,7 +147,7 @@ class BddManager():
                     session.commit()
                     return self.get(id)
                 else:
-                    raise XtremCacheItemNotFoundError(e)
+                    raise XtremCacheItemNotFoundError(id)
         return item
 
     def update(self, item) -> None:
@@ -160,7 +160,7 @@ class BddManager():
                 item_from_bdd.copy_from(item)
                 session.commit()
             except Exception as e:
-                raise XtremCacheItemNotFoundError(e)
+                raise XtremCacheItemNotFoundError(item.id)
 
     def delete(self, id: str):
         """Delete a db Item based on its id."""
@@ -169,7 +169,7 @@ class BddManager():
             try:
                 session.query(self.Item).filter(self.Item.id.in_([id])).delete()
                 session.commit()
-                logging.info(f'"{id}" have been remove from cache db.')
+                logging.info(f'"{id}" have been removed from cache db.')
             except Exception as e:
                 raise XtremCacheRemoveError(e)
 
@@ -191,16 +191,16 @@ class BddManager():
             try:
                 values = session.query(member).all()
             except Exception as e:
-                raise XtremCacheItemNotFoundError(e)
+                raise XtremCacheItemNotFoundError('anything')
         return list(map(lambda v: v[0], values))
 
     @property
-    def older(self):
+    def oldest(self):
         """Return the older db Item."""
 
         with Session(self.__engine) as session:
             try:
                 item = session.query(self.Item).order_by(self.Item.created_date.asc()).first()
             except Exception as e:
-                raise XtremCacheItemNotFoundError(e)
+                raise XtremCacheItemNotFoundError('the oldest item')
         return item
