@@ -1,8 +1,8 @@
 import logging
 import os
 import time
+from typing import List
 
-from xtremcache import log_level
 from xtremcache.archivermanager import create_archiver
 from xtremcache.bddmanager import BddManager
 from xtremcache.configuration import ConfigurationLevel, ConfigurationManager
@@ -12,16 +12,21 @@ from xtremcache.utils import *
 class CacheManager():
     """All actions to do when file or directory is cached or exit from the cache."""
 
-    DELAY_TIME = 0.5
-    DEFAULT_TIMEOUT = 60
+    VERBOSE = logging.DEBUG
+    INFO = logging.INFO
+    QUIET = logging.ERROR
 
-    def __init__(self, cache_dir: str = None, max_size: str = None, verbosity: int = log_level.WARNING) -> None:
+    _DELAY_TIME = 0.5
+    _DEFAULT_TIMEOUT = 60
+
+    def __init__(self, cache_dir: str = None, max_size: str = None, log_level: int = logging.WARNING) -> None:
         self.__config = ConfigurationManager(cache_dir=cache_dir, max_size=max_size)
         self.__archiver = create_archiver(self.__config.cache_dir)
         logging.basicConfig(
-            level=verbosity,
-            format='[XtremCache %(levelname)s - %(asctime)s]: %(message)s')
-        self.__bdd_manager = BddManager(self.__config.cache_dir, verbosity)
+            level=log_level,
+            format='[xtremcache %(levelname)s - %(asctime)s]: %(message)s',
+            datefmt='%H:%M:%S')
+        self.__bdd_manager = BddManager(self.__config.cache_dir, log_level)
 
     @property
     def cache_dir(self):
@@ -38,7 +43,7 @@ class CacheManager():
             force: bool = False,
             compression_level: int = 6,
             excluded: List[str] = [],
-            timeout: int = DEFAULT_TIMEOUT) -> None:
+            timeout: int = _DEFAULT_TIMEOUT) -> None:
         """Put the file or dir at the given path in cache."""
 
         def _cache(
@@ -70,24 +75,22 @@ class CacheManager():
                     item.writer = False
                     item.archive_path = os.path.relpath(archive_path, cache_dir)
                     bdd.update(item)
-                    logging.info(f'"{id}" have been store in cache db.')
+                    logging.info(f'"{id}" is cached.')
                     if item.size < (self.max_size - bdd.size):
                         self.__max_size_cleaning()
                     else:
                         self.remove(id)
-                        raise XtremCacheMaxSizeCachedError(
-                            f'Impossible to cache "{id}" item because the archive is too big.')  
+                        raise XtremCacheMaxSizeCachedError(id)
             else:
                 if force:
                     self.remove(id)
                     _cache(id, path, False)
                 else:
-                    raise XtremCacheAlreadyCachedError(
-                        f'An "{id}" item is already cached. Use "--force" option if you want to overwrite it.')
+                    raise XtremCacheAlreadyCachedError(id)
 
         timeout_exec(timeout, _cache, id, path, force, compression_level, excluded)
 
-    def uncache(self, id: str, path: str, timeout: int = DEFAULT_TIMEOUT) -> None:
+    def uncache(self, id: str, path: str, timeout: int = _DEFAULT_TIMEOUT) -> None:
         """Extract the archive with the given id at the given path."""
 
         def _uncache(id: str, path: str) -> None:
@@ -96,25 +99,25 @@ class CacheManager():
             try:
                 item = bdd.get(id)
             except XtremCacheItemNotFoundError as e:
-                logging.error(f'Unable to find "{id}" in cache db.')
+                logging.error(f'Impossible to find "{id}"')
                 raise e
             if item.can_read:
                 item.readers = item.readers + 1
                 bdd.update(item)
                 try:
                     archiver.extract(id, path)
-                    logging.info(f'"{id}" have been uncache at {path}.')
+                    logging.info(f'"{id}" was uncached to {path}.')
                 except XtremCacheArchiveExtractionError as e:
                     item.readers = item.readers - 1
                     bdd.update(item)
                     self.remove(id)
-                    raise XtremCacheArchiveExtractionError(e)
+                    raise e
                 else:
                     item.readers = item.readers - 1
                     bdd.update(item)
             else:
-                time.sleep(self.DELAY_TIME)
-                raise FunctionRetry()
+                time.sleep(self._DELAY_TIME)
+                raise FunctionRecallAsked(_uncache)
 
         timeout_exec(timeout, _uncache, id, path)
 
@@ -130,12 +133,12 @@ class CacheManager():
         all_sizes.append(bdd.size)
         if len(all_sizes):
             if sum(all_sizes) >= self.max_size:
-                self.remove(bdd.older.id)
-                removed_list.append(bdd.older)
+                self.remove(bdd.oldest.id)
+                removed_list.append(bdd.oldest)
                 self.__max_size_cleaning(removed_list)
         return removed_list
 
-    def remove(self, id: str = None, timeout: int = DEFAULT_TIMEOUT) -> None:
+    def remove(self, id: str = None, timeout: int = _DEFAULT_TIMEOUT) -> None:
         """Delete an archive based on its id."""
 
         def _remove(id: int) -> None:
@@ -143,12 +146,12 @@ class CacheManager():
             cache_dir = self.cache_dir
             ids = [id] if id else bdd.get_all_values(bdd.Item.id)
             if not ids:
-                logging.info('Cache db is empty, nothing to remove.')
+                logging.info('Empty cache, nothing to remove.')
             for id in ids:
                 try:
                     item = bdd.get(id)
                 except XtremCacheItemNotFoundError as e:
-                    logging.error(f'Unable to find "{id}" in cache db.')
+                    logging.error(f'Unable to find "{id}".')
                     raise e
                 if item.can_modifie:
                     item.writer = True
@@ -161,11 +164,11 @@ class CacheManager():
                             os.remove(item.archive_path)
                         os.chdir(c_cwd)
                     except Exception as e:
-                        raise XtremCacheArchiveRemovingError(e)
+                        raise XtremCacheArchiveRemovingError(id, e)
                     bdd.delete(item.id)
                 else:
-                    time.sleep(self.DELAY_TIME)
-                    raise FunctionRetry()
+                    time.sleep(self._DELAY_TIME)
+                    raise FunctionRecallAsked(_remove)
 
         timeout_exec(timeout, _remove, id)
 
