@@ -4,28 +4,24 @@ from abc import ABC, abstractproperty
 from enum import Enum
 from functools import lru_cache
 from typing import List
+from pathlib import Path
 
 import yaml
-from tabulate import tabulate
+from tabulate import tabulate, SEPARATING_LINE
 
 from xtremcache.utils import *
+from xtremcache.version import __app_name__
 
 
 class ConfigurationLevel(Enum):
     HARD_CODED = 'Default'
     GLOBAL_FILE = 'Global file'
     LOCAL_FILE = 'Local file'
-    ENV_VAR = 'Environement variables'
+    ENV_VAR = 'Environment variables'
     RUNTIME = 'Runtime'
 
 
 class Configuration(ABC):
-    @abstractproperty
-    def id_(self) -> str:
-        """Return a unique printable / readable identifier for this configuration."""
-
-        pass
-
     @abstractproperty
     def cache_dir(self) -> str:
         """Compute and return the dir location of all archive database."""
@@ -38,6 +34,15 @@ class Configuration(ABC):
 
         pass
 
+    def __init__(self, id_) -> None:
+        self.__id = id_
+
+    @property
+    def id_(self) -> str:
+        """Return a unique printable / readable identifier for this configuration."""
+
+        return self.__id
+
     @property
     def is_set_cache_dir(self) -> bool:
         """Return True if the cache_dir variable is set in this config."""
@@ -53,26 +58,18 @@ class Configuration(ABC):
     def set_cache_dir(self, value: str) -> None:
         """Update the cahe_dir value. (Not mandatory)"""
 
-        raise NotImplementedError(f'This type of configuration ({self.id_} do not allow cache_dir updates.')
+        raise NotImplementedError(f'This type of configuration ({self.id_}) do not allow cache_dir updates.')
 
     def set_max_size(self, value: str) -> None:
         """Update the max_size value. (Not mandatory)"""
 
-        raise NotImplementedError(f'This type of configuration ({self.id_} do not allow max_size updates.')
+        raise NotImplementedError(f'This type of configuration ({self.id_}) do not allow max_size updates.')
 
 
 class HardcodedConfiguration(Configuration):
-    @property
-    def id_(self) -> str:
-        return ConfigurationLevel.HARD_CODED.value
-
     @property
     def cache_dir(self) -> str:
-        if isUnix():
-            path = os.path.join('~', f'.{get_app_name()}')
-        else:
-            path = os.path.join(os.getenv('LOCALAPPDATA'), f'.{get_app_name()}')
-        return path
+        return os.path.join(get_configuration_location(), 'data')
 
     @property
     def max_size(self) -> int:
@@ -88,9 +85,9 @@ class HardcodedConfiguration(Configuration):
 
 
 class FileConfiguration(Configuration, ABC):
-    @abstractproperty
-    def config_path(self) -> str:
-        pass
+    def __init__(self, id_, confg_path) -> None:
+        self.__config_path = confg_path
+        super().__init__(id_)
 
     def _read_yaml_properties(self) -> dict:
         file_content = dict()
@@ -99,6 +96,10 @@ class FileConfiguration(Configuration, ABC):
                 file_content = yaml.safe_load(f)
         return file_content
 
+    @property
+    def config_path(self) -> str:
+        return self.__config_path
+
     @property
     def cache_dir(self) -> str:
         return self._read_yaml_properties().get('cache_dir')
@@ -125,34 +126,7 @@ class FileConfiguration(Configuration, ABC):
             yaml.safe_dump(file_content, f, default_flow_style=False)
 
 
-class HomeFileConfiguration(FileConfiguration):
-    @property
-    def config_path(self) -> str:
-        if isUnix():
-            return os.path.join('~', f'.{get_app_name()}', 'config.yml')
-        else:
-            return os.path.join(os.getenv('LOCALAPPDATA'), f'.{get_app_name()}', 'config.yml')
-
-    @property
-    def id_(self) -> str:
-        return ConfigurationLevel.GLOBAL_FILE.value
-
-
-class LocalFileConfiguration(FileConfiguration):
-    @property
-    def config_path(self) -> str:
-        return os.path.join('.', 'config.yml')
-
-    @property
-    def id_(self) -> str:
-        return ConfigurationLevel.LOCAL_FILE.value
-
-
 class EnvironementConfiguration(Configuration):
-    @property
-    def id_(self) -> str:
-        return ConfigurationLevel.ENV_VAR.value
-
     @property
     def cache_dir(self) -> str:
         return self.__env_cache_dir()
@@ -169,14 +143,10 @@ class EnvironementConfiguration(Configuration):
 
 
 class RuntimeConfiguration(Configuration):
-    def __init__(self, cache_dir: str, max_size: str, *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
+    def __init__(self, id_, cache_dir: str, max_size: str) -> None:
         self.__max_size = small_to_raw_size(max_size)
         self.__cache_dir = cache_dir
-
-    @property
-    def id_(self) -> str:
-        return ConfigurationLevel.RUNTIME.value
+        super().__init__(id_)
 
     @property
     def cache_dir(self) -> str:
@@ -193,16 +163,19 @@ class ConfigurationManager:
             configuration_priority: List[Configuration] = None,
             cache_dir: str = None,
             max_size: str = None) -> None:
+        # If no configuration list are past use the standard one.
         if configuration_priority:
             self.__configuration_priority = configuration_priority
         else:
             self.__configuration_priority = [
-                HardcodedConfiguration(),
-                HomeFileConfiguration(),
-                LocalFileConfiguration(),
-                EnvironementConfiguration(),
+                HardcodedConfiguration(ConfigurationLevel.HARD_CODED.value),
+                FileConfiguration(ConfigurationLevel.GLOBAL_FILE.value, os.path.join(get_configuration_location(), 'config.yml')),
+                FileConfiguration(ConfigurationLevel.LOCAL_FILE.value, os.path.join('.', 'config.yml')),
+                EnvironementConfiguration(ConfigurationLevel.ENV_VAR.value),
             ]
-        self.__configuration_priority.append(RuntimeConfiguration(cache_dir, max_size))
+        # In anycase the runtime configuration is top level priority.
+        self.__configuration_priority.append(
+            RuntimeConfiguration(ConfigurationLevel.RUNTIME.value, cache_dir, max_size))
 
 
     @property
@@ -246,19 +219,17 @@ class ConfigurationManager:
 
     def display(self):
         """Print the full configuration thanks to tabulate lib."""
-
-        not_defined_value = 'Not defined'
         config_table = [
             [
                 c.id_,
-                c.cache_dir if c.is_set_cache_dir else not_defined_value,
-                raw_to_small_size(c.max_size) if c.is_set_max_size else not_defined_value
+                c.cache_dir,
+                raw_to_small_size(c.max_size)
             ]
             for c in self.__configuration_priority
         ]
-        header = ['Origin', 'cache_dir', 'max_size']
-        footer = [['Used values', self.cache_dir, raw_to_small_size(self.max_size)]]
-        print(tabulate(config_table + footer, header, tablefmt='psql'))
+        header = ['', 'cache_dir', 'max_size']
+        footer = [SEPARATING_LINE, ['Used', self.cache_dir, raw_to_small_size(self.max_size)]]
+        print(tabulate(config_table + footer, header, tablefmt='simple', missingval="Not defined"))
 
 
 def small_to_raw_size(small_size: str) -> int:
@@ -281,7 +252,7 @@ def small_to_raw_size(small_size: str) -> int:
         raise XtremCacheInputError(
             f'Invalid max_size format: get {small_size}, correct format are \d+[TGMtgm]? e.g.: \'5g\', \'100m\', \'5000\' or \'1t\'.')
 
-def raw_to_small_size(raw_size: int) -> str: # TODO everything
+def raw_to_small_size(raw_size: int) -> str:
     """Interpret the given raw_size int from bytes to terra, giga, mega or bytes.
 
     Choose the largest multiplicator possible.
@@ -300,3 +271,10 @@ def raw_to_small_size(raw_size: int) -> str: # TODO everything
             return f'{small_size_int}{symbol}'
     else:
         return str(raw_size)
+
+def get_configuration_location() -> str:
+    """Provide configuration location"""
+
+    path = Path.home() if is_unix() else os.getenv('LOCALAPPDATA')
+    path = os.path.join(path, f'.{__app_name__}')
+    return os.path.abspath(os.path.realpath(path))
